==> ejc-assistrmat-impl-3.0.0-20220322.020504-1-sources.jar: com/ejianc/business/assist/rmat/bean/SettleScrapEntity.java <==
package com.ejianc.business.assist.rmat.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 结算单-报废赔偿金额
 *
 * @author generator
 */
@TableName("ejc_prormat_settle_scrap")
public class SettleScrapEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value = "settle_id")
    private Long settleId; // 结算id
    @TableField(value = "source_id")
    private Long sourceId; // 来源数据Id
    @TableField(value = "restitute_bill_code")
    private String restituteBillCode; // 退赔单据编码
    @TableField(value = "compensate_tax_mny")
    private BigDecimal compensateTaxMny; // 本次赔偿金额
    @TableField(value = "compensate_mny")
    private BigDecimal compensateMny; // 本次赔偿金额(无税)
    @TableField(value = "compensate_tax")
    private BigDecimal compensateTax; // 赔偿税额
    @TableField(value = "refund_date")
    private Date refundDate; // 退赔日期
    @TableField(value = "memo")
    private String memo; // 备注


    public Long getSettleId() {
        return settleId;
    }

    public void setSettleId(Long settleId) {
        this.settleId = settleId;
    }

    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }

    public String getRestituteBillCode() {
        return restituteBillCode;
    }

    public void setRestituteBillCode(String restituteBillCode) {
        this.restituteBillCode = restituteBillCode;
    }

    public BigDecimal getCompensateTaxMny() {
        return compensateTaxMny;
    }

    public void setCompensateTaxMny(BigDecimal compensateTaxMny) {
        this.compensateTaxMny = compensateTaxMny;
    }

    public BigDecimal getCompensateMny() {
        return compensateMny;
    }

    public void setCompensateMny(BigDecimal compensateMny) {
        this.compensateMny = compensateMny;
    }

    public BigDecimal getCompensateTax() {
        return compensateTax;
    }

    public void setCompensateTax(BigDecimal compensateTax) {
        this.compensateTax = compensateTax;
    }

    public Date getRefundDate() {
        return refundDate;
    }

    public void setRefundDate(Date refundDate) {
        this.refundDate = refundDate;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

}

==> ejc-assistrmat-impl-3.0.0-20220913.095806-187-sources.jar: com/ejianc/business/assist/rmat/bean/SettleScrapEntity.java <==
package com.ejianc.business.assist.rmat.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 结算单-报废赔偿金额
 *
 * @author generator
 */
@TableName("ejc_assistrmat_settle_scrap")
public class SettleScrapEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value = "settle_id")
    private Long settleId; // 结算id
    @TableField(value = "source_id")
    private Long sourceId; // 来源数据Id
    @TableField(value = "restitute_bill_code")
    private String restituteBillCode; // 退赔单据编码
    @TableField(value = "compensate_tax_mny")
    private BigDecimal compensateTaxMny; // 本次赔偿金额
    @TableField(value = "compensate_mny")
    private BigDecimal compensateMny; // 本次赔偿金额(无税)
    @TableField(value = "compensate_tax")
    private BigDecimal compensateTax; // 赔偿税额
    @TableField(value = "refund_date")
    private Date refundDate; // 退赔日期
    @TableField(value = "memo")
    private String memo; // 备注


    public Long getSettleId() {
        return settleId;
    }

    public void setSettleId(Long settleId) {
        this.settleId = settleId;
    }

    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }

    public String getRestituteBillCode() {
        return restituteBillCode;
    }

    public void setRestituteBillCode(String restituteBillCode) {
        this.restituteBillCode = restituteBillCode;
    }

    public BigDecimal getCompensateTaxMny() {
        return compensateTaxMny;
    }

    public void setCompensateTaxMny(BigDecimal compensateTaxMny) {
        this.compensateTaxMny = compensateTaxMny;
    }

    public BigDecimal getCompensateMny() {
        return compensateMny;
    }

    public void setCompensateMny(BigDecimal compensateMny) {
        this.compensateMny = compensateMny;
    }

    public BigDecimal getCompensateTax() {
        return compensateTax;
    }

    public void setCompensateTax(BigDecimal compensateTax) {
        this.compensateTax = compensateTax;
    }

    public Date getRefundDate() {
        return refundDate;
    }

    public void setRefundDate(Date refundDate) {
        this.refundDate = refundDate;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

}
